@@ -469,6 +469,13 @@ impl<T, N: ArrayLength<T>> Index<Range<usize>> for NumericArray<T, N> {
     }
 }
 
+impl<T, N: ArrayLength<T>> IndexMut<Range<usize>> for NumericArray<T, N> {
+    #[inline(always)]
+    fn index_mut(&mut self, index: Range<usize>) -> &mut [T] {
+        self.0.index_mut(index)
+    }
+}
+
 impl<T, N: ArrayLength<T>> Index<RangeTo<usize>> for NumericArray<T, N> {
     type Output = [T];
 
@@ -478,6 +485,13 @@ impl<T, N: ArrayLength<T>> Index<RangeTo<usize>> for NumericArray<T, N> {
     }
 }
 
+impl<T, N: ArrayLength<T>> IndexMut<RangeTo<usize>> for NumericArray<T, N> {
+    #[inline(always)]
+    fn index_mut(&mut self, index: RangeTo<usize>) -> &mut [T] {
+        self.0.index_mut(index)
+    }
+}
+
 impl<T, N: ArrayLength<T>> Index<RangeFrom<usize>> for NumericArray<T, N> {
     type Output = [T];
 
@@ -487,6 +501,13 @@ impl<T, N: ArrayLength<T>> Index<RangeFrom<usize>> for NumericArray<T, N> {
     }
 }
 
+impl<T, N: ArrayLength<T>> IndexMut<RangeFrom<usize>> for NumericArray<T, N> {
+    #[inline(always)]
+    fn index_mut(&mut self, index: RangeFrom<usize>) -> &mut [T] {
+        self.0.index_mut(index)
+    }
+}
+
 impl<T, N: ArrayLength<T>> Index<RangeFull> for NumericArray<T, N> {
     type Output = [T];
 
@@ -496,6 +517,13 @@ impl<T, N: ArrayLength<T>> Index<RangeFull> for NumericArray<T, N> {
     }
 }
 
+impl<T, N: ArrayLength<T>> IndexMut<RangeFull> for NumericArray<T, N> {
+    #[inline(always)]
+    fn index_mut(&mut self, _index: RangeFull) -> &mut [T] {
+        self
+    }
+}
+
 impl<'a, T, N: ArrayLength<T>> IntoIterator for &'a NumericArray<T, N> {
     type Item = &'a T;
     type IntoIter = slice::Iter<'a, T>;
@@ -613,8 +641,8 @@ pub mod tests {
 
     #[test]
     fn test_classify() {
-        use num_traits::Float;
         use core::num::FpCategory;
+        use num_traits::Float;
 
         let nan = f32::nan();
         let infinity = f32::infinity();
